@@ -22,6 +22,7 @@
 from __future__ import print_function
 
 import gzip
+import io
 import os
 import platform
 import pwd
@@ -64,7 +65,7 @@ def cleanup_after(func):
                 self.db.progress('STOP')
             except (KeyboardInterrupt, SystemExit):
                 raise
-            except:
+            except Exception:
                 pass
     return wrapper
 
@@ -87,7 +88,10 @@ class Install(install_misc.InstallBase):
     def __init__(self):
         install_misc.InstallBase.__init__(self)
 
-        self.db = debconf.Debconf()
+        self.db = debconf.Debconf(
+            read=io.TextIOWrapper(sys.stdin.buffer, encoding='utf-8'),
+            write=io.TextIOWrapper(sys.stdout.buffer, encoding='utf-8'))
+
         self.kernel_version = platform.release()
 
         # Get langpacks from install
@@ -240,7 +244,7 @@ class Install(install_misc.InstallBase):
         self.db.progress('INFO', 'ubiquity/install/apt_clone_restore')
         try:
             self.apt_clone_restore()
-        except:
+        except Exception:
             syslog.syslog(
                 syslog.LOG_WARNING,
                 'Could not restore packages from the previous install:')
@@ -250,7 +254,7 @@ class Install(install_misc.InstallBase):
             self.db.go()
         try:
             self.copy_network_config()
-        except:
+        except Exception:
             syslog.syslog(
                 syslog.LOG_WARNING,
                 'Could not copy the network configuration:')
@@ -260,7 +264,7 @@ class Install(install_misc.InstallBase):
             self.db.go()
         try:
             self.copy_bluetooth_config()
-        except:
+        except Exception:
             syslog.syslog(
                 syslog.LOG_WARNING,
                 'Could not copy the bluetooth configuration:')
@@ -270,14 +274,14 @@ class Install(install_misc.InstallBase):
             self.db.go()
         try:
             self.recache_apparmor()
-        except:
+        except Exception:
             syslog.syslog(
                 syslog.LOG_WARNING, 'Could not create an Apparmor cache:')
             for line in traceback.format_exc().split('\n'):
                 syslog.syslog(syslog.LOG_WARNING, line)
         try:
             self.copy_wallpaper_cache()
-        except:
+        except Exception:
             syslog.syslog(
                 syslog.LOG_WARNING, 'Could not copy wallpaper cache:')
             for line in traceback.format_exc().split('\n'):
@@ -748,7 +752,7 @@ class Install(install_misc.InstallBase):
         try:
             if remove_kernels:
                 install_misc.record_removed(remove_kernels, recursive=True)
-        except:
+        except Exception:
             self.db.progress('STOP')
             raise
         self.db.progress('SET', 5)
@@ -1212,6 +1216,13 @@ class Install(install_misc.InstallBase):
                                 '-o', 'oem', '-g', 'oem',
                                 '/%s' % desktop_file,
                                 '/home/oem/Desktop/%s' % desktop_base)
+                            install_misc.chrex(
+                                self.target,
+                                'sudo', '-i', '-u', 'oem',
+                                'dbus-run-session', '--',
+                                'gio', 'set',
+                                '/home/oem/Desktop/%s' % desktop_base,
+                                'metadata::trusted', 'true')
                             break
 
                 # Carry the locale setting over to the installed system.
