@@ -166,7 +166,7 @@ class PageGtk(plugin.PluginUI):
                     # Try a default, usually working locale
                     locale.setlocale(locale.LC_ALL, 'en_US.UTF-8')
                 choices.sort(key=lambda c: locale.strxfrm(c.encode('utf-8')))
-            except:
+            except Exception:
                 # Let's avoid crashing when we get a bad locale
                 choices.sort()
 
@@ -477,6 +477,8 @@ class Page(plugin.Plugin):
             'OVERRIDE_USE_DEBCONF_LOCALE': '1',
             'LC_ALL': di_locale,
             'PATH': '/usr/lib/ubiquity/console-setup:' + os.environ['PATH'],
+            'DPKG_MAINTSCRIPT_NAME': 'postinst',
+            'DPKG_MAINTSCRIPT_PACKAGE': 'keyboard-configuration',
         }
         return command, questions, environ
 
